
# Slot: classification_rules


the collection of classification rules that apply to all members of this class

URI: [linkml:classification_rules](https://w3id.org/linkml/classification_rules)


## Domain and Range

[ClassDefinition](ClassDefinition.md) &#8594;  <sub>0..\*</sub> [AnonymousClassExpression](AnonymousClassExpression.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
